import {model, ObjectId, Schema, Types} from "mongoose";
import { fieldEncryption } from "mongoose-field-encryption";
import process from "process";

export enum ILicenseMetaType {
    STRING
}

export interface ILicenseMeta {
    type: ILicenseMetaType,
    key: string,
    value: string
}

export interface ILicense {
    _id: ObjectId,
    projectId: ObjectId,
    key: string,
    groups?: string[],
    permissions?: string[],
    meta?: ILicenseMeta[],
    expirationDate?: Date
}

const LicenseSchema = new Schema<ILicense>({
    projectId: {
        type: Types.ObjectId,
        required: true
    },
    key: {
        type: String,
        required: true
    },
    groups: [String],
    permissions: [String],
    meta: [Array],
    expirationDate: {
        type: Date,
        default: Date.now
    }
});

LicenseSchema.plugin(fieldEncryption, {
    fields: ["projectId", "key", "groups", "permissions", "meta", "expirationDate"],
    secret: process.env.ENC_KEY,
    saltGenerator: () => process.env.SIG_KEY
});

export const License = model<ILicense>("licenses", LicenseSchema);